/* properties-sidebar.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from properties-sidebar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>


#define BOXES_TYPE_PROPERTIES_SIDEBAR (boxes_properties_sidebar_get_type ())
#define BOXES_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebar))
#define BOXES_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))
#define BOXES_IS_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_IS_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_PROPERTIES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))

typedef struct _BoxesPropertiesSidebar BoxesPropertiesSidebar;
typedef struct _BoxesPropertiesSidebarClass BoxesPropertiesSidebarClass;
typedef struct _BoxesPropertiesSidebarPrivate BoxesPropertiesSidebarPrivate;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

struct _BoxesPropertiesSidebar {
	GtkBox parent_instance;
	BoxesPropertiesSidebarPrivate * priv;
	GtkImage* screenshot;
	GtkListStore* listmodel;
	GtkTreeSelection* selection;
	GtkButton* shutdown_button;
	BoxesMiniGraph* cpu_graph;
	BoxesMiniGraph* io_graph;
	BoxesMiniGraph* net_graph;
};

struct _BoxesPropertiesSidebarClass {
	GtkBoxClass parent_class;
};

struct _BoxesPropertiesSidebarPrivate {
	GtkTreeModelFilter* model_filter;
	BoxesAppWindow* window;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;


static gpointer boxes_properties_sidebar_parent_class = NULL;

GType boxes_properties_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_SIDEBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarPrivate))
enum  {
	BOXES_PROPERTIES_SIDEBAR_DUMMY_PROPERTY
};
void boxes_properties_sidebar_setup_ui (BoxesPropertiesSidebar* self, BoxesAppWindow* window);
static void boxes_properties_sidebar_on_row_activated (BoxesPropertiesSidebar* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
void boxes_properties_set_page (BoxesProperties* self, BoxesPropertiesPage value);
static void _boxes_properties_sidebar_on_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
static void boxes_properties_sidebar_on_shutdown_button_clicked (BoxesPropertiesSidebar* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
static void _boxes_properties_sidebar_on_shutdown_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesPropertiesSidebar* boxes_properties_sidebar_new (void);
BoxesPropertiesSidebar* boxes_properties_sidebar_construct (GType object_type);
static GObject * boxes_properties_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_properties_sidebar_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 31 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	return self ? g_object_ref (self) : NULL;
#line 301 "properties-sidebar.c"
}


void boxes_properties_sidebar_setup_ui (BoxesPropertiesSidebar* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 30 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (self != NULL);
#line 30 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (window != NULL);
#line 31 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp0_ = window;
#line 31 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 31 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->priv->window);
#line 31 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	self->priv->window = _tmp1_;
#line 320 "properties-sidebar.c"
}


static void boxes_properties_sidebar_on_row_activated (BoxesPropertiesSidebar* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column) {
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesProperties* _tmp7_ = NULL;
	GtkListStore* _tmp8_ = NULL;
	GtkTreeIter _tmp9_ = {0};
	GtkTreePath* _tmp10_ = NULL;
	GtkTreePath* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint* _tmp13_ = NULL;
	gint _tmp14_ = 0;
#line 35 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (self != NULL);
#line 35 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (treeview != NULL);
#line 35 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (path != NULL);
#line 35 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (column != NULL);
#line 37 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp0_ = self->priv->model_filter;
#line 37 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp1_ = path;
#line 37 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 37 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	filter_iter = _tmp2_;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp3_ = self->priv->model_filter;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp4_ = filter_iter;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 38 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	iter = _tmp5_;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp6_ = self->priv->window;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp7_ = _tmp6_->properties;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp8_ = self->listmodel;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp9_ = iter;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp10_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp8_, &_tmp9_);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp11_ = _tmp10_;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp13_ = gtk_tree_path_get_indices_with_depth (_tmp11_, &_tmp12_);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp14_ = _tmp13_[0];
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	boxes_properties_set_page (_tmp7_, (BoxesPropertiesPage) _tmp14_);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_gtk_tree_path_free0 (_tmp11_);
#line 386 "properties-sidebar.c"
}


static void _boxes_properties_sidebar_on_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	boxes_properties_sidebar_on_row_activated ((BoxesPropertiesSidebar*) self, _sender, path, column);
#line 393 "properties-sidebar.c"
}


static void boxes_properties_sidebar_on_shutdown_button_clicked (BoxesPropertiesSidebar* self) {
	BoxesLibvirtMachine* machine = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
#line 43 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_return_if_fail (self != NULL);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp0_ = self->priv->window;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp2_ = _tmp1_;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp2_) : NULL);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	machine = _tmp3_;
#line 45 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp4_ = machine;
#line 45 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	if (_tmp4_ != NULL) {
#line 420 "properties-sidebar.c"
		BoxesLibvirtMachine* _tmp5_ = NULL;
#line 46 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
		_tmp5_ = machine;
#line 46 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
		boxes_libvirt_machine_force_shutdown (_tmp5_, TRUE);
#line 426 "properties-sidebar.c"
	}
#line 43 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (machine);
#line 430 "properties-sidebar.c"
}


static void _boxes_properties_sidebar_on_shutdown_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	boxes_properties_sidebar_on_shutdown_button_clicked ((BoxesPropertiesSidebar*) self);
#line 437 "properties-sidebar.c"
}


BoxesPropertiesSidebar* boxes_properties_sidebar_construct (GType object_type) {
	BoxesPropertiesSidebar * self = NULL;
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	self = (BoxesPropertiesSidebar*) g_object_new (object_type, NULL);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	return self;
#line 447 "properties-sidebar.c"
}


BoxesPropertiesSidebar* boxes_properties_sidebar_new (void) {
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	return boxes_properties_sidebar_construct (BOXES_TYPE_PROPERTIES_SIDEBAR);
#line 454 "properties-sidebar.c"
}


static GObject * boxes_properties_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesPropertiesSidebar * self;
	GtkTreeModelFilter* _tmp0_ = NULL;
#line 26 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	parent_class = G_OBJECT_CLASS (boxes_properties_sidebar_parent_class);
#line 26 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 26 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebar);
#line 27 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_tmp0_ = self->priv->model_filter;
#line 27 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_tree_model_filter_set_visible_column (_tmp0_, 1);
#line 26 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	return obj;
#line 475 "properties-sidebar.c"
}


static void boxes_properties_sidebar_class_init (BoxesPropertiesSidebarClass * klass) {
	gint BoxesPropertiesSidebar_private_offset;
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	boxes_properties_sidebar_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesSidebarPrivate));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_properties_sidebar_constructor;
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_sidebar_finalize;
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	BoxesPropertiesSidebar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/properties-sidebar.ui");
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "screenshot", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, screenshot));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "listmodel", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, listmodel));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "model_filter", FALSE, BoxesPropertiesSidebar_private_offset + G_STRUCT_OFFSET (BoxesPropertiesSidebarPrivate, model_filter));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selection", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, selection));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "shutdown_button", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, shutdown_button));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cpu_graph", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, cpu_graph));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "io_graph", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, io_graph));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "net_graph", FALSE, G_STRUCT_OFFSET (BoxesPropertiesSidebar, net_graph));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_row_activated", G_CALLBACK(_boxes_properties_sidebar_on_row_activated_gtk_tree_view_row_activated));
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_shutdown_button_clicked", G_CALLBACK(_boxes_properties_sidebar_on_shutdown_button_clicked_gtk_button_clicked));
#line 513 "properties-sidebar.c"
}


static void boxes_properties_sidebar_instance_init (BoxesPropertiesSidebar * self) {
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	self->priv = BOXES_PROPERTIES_SIDEBAR_GET_PRIVATE (self);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	g_type_ensure (BOXES_TYPE_MINI_GRAPH);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 524 "properties-sidebar.c"
}


static void boxes_properties_sidebar_finalize (GObject* obj) {
	BoxesPropertiesSidebar * self;
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebar);
#line 8 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->screenshot);
#line 10 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->listmodel);
#line 12 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 14 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->selection);
#line 16 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->shutdown_button);
#line 18 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->cpu_graph);
#line 20 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->io_graph);
#line 22 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->net_graph);
#line 24 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	_g_object_unref0 (self->priv->window);
#line 6 "/home/mclasen/Sources/gnome-boxes/src/properties-sidebar.vala"
	G_OBJECT_CLASS (boxes_properties_sidebar_parent_class)->finalize (obj);
#line 552 "properties-sidebar.c"
}


GType boxes_properties_sidebar_get_type (void) {
	static volatile gsize boxes_properties_sidebar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_sidebar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesSidebarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_sidebar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesSidebar), 0, (GInstanceInitFunc) boxes_properties_sidebar_instance_init, NULL };
		GType boxes_properties_sidebar_type_id;
		boxes_properties_sidebar_type_id = g_type_register_static (gtk_box_get_type (), "BoxesPropertiesSidebar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_sidebar_type_id__volatile, boxes_properties_sidebar_type_id);
	}
	return boxes_properties_sidebar_type_id__volatile;
}



